import hid
from time import sleep


class MoRFeus(object):
    # Information based of the protocol description by Abhishek on the othernet forum :
    # https://forums.othernet.is/t/rf-product-morfeus-frequency-converter-and-signal-generator/5025/59

    # Constants
    LOmax = 5400000000  # Local Oscillator max (5400MHz)
    LOmin = 85000000  # Local Oscillator min (85Mhz)
    mil = 1000000  # Saves some zero's here and there
    SET = 1
    GET = 0
    vendorID = 0x10c4
    productID = 0xeac9

    msgArray = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
    getMsg = [0, 114]
    setMsg = [0, 119]
    # 8 byte value carrier
    read_buffer = [0, 0, 0, 0, 0, 0, 0, 0]
    # 6 byte trailers
    sixZero = [0, 0, 0, 0, 0, 0]
    # Function Constants
    funcFrequency = 129
    funcMixGen = 130
    funcCurrent = 131  # 0 - 7
    funcBiasTee = 132  # 1 On : 0 Off
    funcLCD = 133  # 0 : Always on, 1 : 10s, 2 : 60s
    funcFW = 134
    funcRegister = 0

    # Housekeeping for remembering GUI vars when pressing the noise button
    initFreq = 433.92

    def __init__(self, device):
        self.device = device

    @classmethod
    def find(cls) -> int:
        while True:
                try:
                    count = 0
                    for d in hid.enumerate(0, 0):
                        keys = list(d.keys())
                        for key in keys:
                            if d[key] == MoRFeus.productID:
                                count = count + 1
                    if count == 0:
                        raise OSError
                    else:
                        return count
                except OSError:
                    print('\nNo moRFeus found... Retrying in 5 seconds')
                    sleep(5)
                    continue

    # init routine for moRFeus
    @classmethod
    def initdevice(cls, vid=vendorID, pid=productID, index=0):
            mrfdevice = hid.enumerate(vid, pid)[index]
            device = hid.device()
            # moRFeus VendorID/ProductID
            device.open_path(mrfdevice['path'])
            device.set_nonblocking(0)
            return device

    def writemsgbytes(self, value, array):
        input_array = value.to_bytes(len(self.read_buffer), 'big')
        for x in range(3, 11):
            self.msgArray[x] = input_array[x - 3]
            array.append(self.msgArray[x])
        for x in range(0, 6):
            array.append(self.sixZero[x])
        self.device.write(array)

    def message(self, mode, func, value):
        outputarray = []
        # this sets the mode, 0: get and 1: set
        while True:
            for x in range(0, 2):
                if mode == self.SET:
                    self.msgArray[x] = self.setMsg[x]
                    outputarray.append(self.msgArray[x])
                else:
                    self.msgArray[x] = self.getMsg[x]
                    outputarray.append(self.msgArray[x])
            # we have an variable array with our mode set...
            # now we should set the function... its always at the same position
            outputarray.append(func)
            # set the value_array
            if func == self.funcFrequency and mode == self.SET:
                freq = int(value * self.mil)
                self.writemsgbytes(freq, outputarray)
                break
            else:
                self.writemsgbytes(value, outputarray)
                break

    # read function byte and return values accordingly
    def readDevice(self):
        read_array = self.device.read(16)
        if read_array:
            for x in range(3, 11):
                self.msgArray[x] = read_array[x - 1]
                # reads byte array and places it in 8 byte array to
                self.read_buffer[x - 3] = self.msgArray[x]
            init_values = int.from_bytes(self.read_buffer, byteorder='big', signed=False)
            if read_array[1] == self.funcFrequency:
                print('Freq :', str.format('{0:.6f}', init_values / self.mil))
                self.initFreq = init_values / self.mil
                return init_values / self.mil
            if read_array[1] == self.funcCurrent:
                print('Curr :', init_values)
                return init_values
            if read_array[1] == self.funcMixGen:
                if init_values == 0:
                    print("Func : Mixer")
                else:
                    print("Func : Generator")
            if read_array[1] == self.funcLCD:
                if init_values == 0:
                    print("LCD  : Always On")
                if init_values == 1:
                    print("LCD  : 10s")
                else:
                    print("LCD  : 60s")
            if read_array[1] == self.funcBiasTee:
                if init_values == 0:
                    print("Bias : Off")
                if init_values == 1:
                    print("Bias : On")

    @classmethod
    def printProgressBar(cls, iteration, total, prefix='', suffix='', decimals=1, length=100, fill='|'):
        """
        Call in a loop to create terminal progress bar
        @params:
            iteration   - Required  : current iteration (Int)
            total       - Required  : total iterations (Int)
            prefix      - Optional  : prefix string (Str)
            suffix      - Optional  : suffix string (Str)
            decimals    - Optional  : positive number of decimals in percent complete (Int)
            length      - Optional  : character length of bar (Int)
            fill        - Optional  : bar fill character (Str)
        """
        if iteration >= 1:
            percent = ("{0:." + str(decimals) + "f}").format(100 * (iteration / float(total)))
            filledLength = int(length * iteration // total)
            bar = fill * filledLength + '-' * (length - filledLength)
            print('\r%s |%s| %s%% %s' % (prefix, bar, percent, suffix), end='\r')
            # Print New Line on Complete
            if iteration == total:
                print()





# Main Loop
import sys
import signal
from PyQt5.QtWidgets import QApplication
from moRFeusQt import mrfqt as mRFsApp
from moRFeusQt import mrf
signal.signal(signal.SIGINT, signal.SIG_DFL)


def main():
    app = QApplication(sys.argv)
    devicecount = mrf.MoRFeus.find()
    devices = []
    for i in range(0, devicecount):
        devices.append(mRFsApp.MoRFeusQt(i))
        print('--------------------\nmoRFeus Dev', i, 'Stats\n--------------------')
        devices[i].getStats()
        print('--------------------\nDevice Output\n--------------------')
        devices[i].show()
    sys.exit(app.exec_())


if __name__ == "__main__":
    main()



#!/usr/bin/env python
# moRFeus python script for interfacing directly via the HID protocol
import time
from moRFeusQt import mrf
from moRFeusQt import mrfmorse
from moRFeusQt import mrfui
from PyQt5.QtGui import QCloseEvent
from PyQt5.QtWidgets import QMainWindow
from PyQt5.QtCore import Qt


class MoRFeusQt(QMainWindow, mrfui.Ui_mRFsMain):
    def __init__(self, devindex):
        super(MoRFeusQt, self).__init__()
        self.setupUi(self)
        self.device = mrf.MoRFeus.initdevice(index=devindex)
        self.devindex = devindex
        self.moRFeus = mrf.MoRFeus(self.device)
        self.morseCode = mrfmorse.MorseCode(self.device)
        # button actions when triggered
        self.startFreq.editingFinished.connect(self.statfreqQt)
        self.startFreq.valueChanged.connect(self.setEnd)
        self.stepSize.valueChanged.connect(self.setStep)
        self.powerInput.editingFinished.connect(self.curQt)
        self.steps.editingFinished.connect(self.setHops)
        self.mixButton.clicked.connect(self.mixQt)
        self.genButton.clicked.connect(self.genQt)
        self.noiseButton.clicked.connect(self.noiseQt)
        self.sweepButton.clicked.connect(self.sweepQt)
        self.biasOn.clicked.connect(self.biasOnQt)
        self.biasOff.clicked.connect(self.biasOffQt)
        self.morseButton.clicked.connect(self.sendMorse)
        # self.morseInput.returnPressed.connect(self.sendMorse)
        self.readRegButton.clicked.connect(self.getReg)

    def closeEvent(self, event: QCloseEvent):
        print("\n--------------------\nSee you next time...\n--------------------")

        # I don't believe that leaving the device at 5400Mhz should be
        # allowed in this application on close, unless you started
        # with that frequency. Disconnect OUT once done

        self.check5400()
        self.device.close()
        super().closeEvent(event)

    def keyPressEvent(self, event):
        if event.key() == Qt.Key_Escape:
            self.close()

    def check5400(self):
        if self.startFreq.value() == 5400:
            self.moRFeus.message(self.moRFeus.SET, self.moRFeus.funcFrequency, self.moRFeus.initFreq)
            self.startFreq.setValue(self.moRFeus.initFreq)

    # The Get functions
    def getStats(self):
        self.getFunc()
        self.getFreq()
        self.getBias()
        self.getCur()
        self.getLCD()

    # Get frequency from device and set Qt spinbox accordingly
    def getFreq(self):
        # Get Frequency message :
        # Object(moRFeus) sends message to device : a '0'(get) frequency
        self.moRFeus.message(self.moRFeus.GET, self.moRFeus.funcFrequency, 0)
        # read and then set response from device
        self.startFreq.setValue(self.moRFeus.readDevice())

    # Get current from device and set Qt spinbox accordingly
    def getCur(self):
        # Get Current message :
        # Object(moRFeus) sends message to device : a '0'(get) current
        self.moRFeus.message(self.moRFeus.GET, self.moRFeus.funcCurrent, 0)
        # read and then set response from device
        self.powerInput.setValue(self.moRFeus.readDevice())

    # Get function from device : 1 for Generator 0 for Mixer mode
    def getFunc(self):
        # Get Function message :
        # Object(moRFeus) sends message to device : a '0'(get) function
        self.moRFeus.message(self.moRFeus.GET, self.moRFeus.funcMixGen, 0)
        # read and then set response from device
        self.moRFeus.readDevice()

    # Get register '0' from device and set Qt hex text accordingly
    def getReg(self):
        self.moRFeus.message(self.moRFeus.GET, self.moRFeus.funcRegister, 0)
        while True:
            read_array = self.device.read(16)
            if read_array:
                for x in range(0, 16):
                    self.moRFeus.msgArray[x] = read_array[x]
                for y in range(3, 11):
                    self.moRFeus.read_buffer[y - 3] = self.moRFeus.msgArray[y]
                print(self.devindex, 'Read Data   : ', read_array)
                reg = int.from_bytes(self.moRFeus.read_buffer, byteorder='big', signed=False)
                hexy = hex(reg)[0:]
                self.readReg.setText(hexy)
                break

    # Get LCD value from device
    def getLCD(self):
        # Get LCD message :
        # Object(moRFeus) sends message to device : a '0'(get) LCD
        self.moRFeus.message(self.moRFeus.GET, self.moRFeus.funcLCD, 0)
        # read and then set response from device
        self.moRFeus.readDevice()

    # Get LCD value from device
    def getBias(self):
        # Get BiasTee message :
        # Object(moRFeus) sends message to device : a '0'(get) biasTee
        self.moRFeus.message(self.moRFeus.GET, self.moRFeus.funcBiasTee, 0)
        # read and then set response from device
        self.moRFeus.readDevice()

    # loop for moving upward in frequency (increases with step)
    @classmethod
    def freqRange(cls, start, end, step):
        while start <= end:
            yield start
            start += step

    # The Set functions

    def setHops(self):
        self.endFreq.setValue(self.startFreq.value() + ((self.stepSize.value() / 1000) * self.steps.value()))
        # self.stepSize.setValue(abs(self.endFreq.value() - self.startFreq.value()))

    def setStep(self):
        self.steps.setValue(abs(self.endFreq.value() - self.startFreq.value()) / (self.stepSize.value() / 1000))

    # set endFreq by startfreq value + stepInput
    def setEnd(self):
        self.endFreq.setValue(self.startFreq.value() + (self.stepSize.value() / 1000 * self.steps.value()))

    # Setting of the device LCD
    # 0 : 'Always On', 1 : '10s', 2 : '60s'
    def setLCD(self):
        # Set LCD message :
        # Object(moRFeus) sends message to device : a '1'(set) LCD
        self.moRFeus.message(self.moRFeus.SET, self.moRFeus.funcLCD, 1)

    # Setting of the device biasTee On
    def biasOnQt(self):
        self.moRFeus.message(self.moRFeus.SET, self.moRFeus.funcBiasTee, 1)
        print(self.devindex, "Bias         :  On")

    # Setting of the device biasTee Off
    def biasOffQt(self):
        self.moRFeus.message(self.moRFeus.SET, self.moRFeus.funcBiasTee, 0)
        print(self.devindex, "Bias         :  Off")

    # Setting of the device current
    def curQt(self):
        while self.device:
            try:
                cur = self.powerInput.value()
                self.moRFeus.message(self.moRFeus.SET, self.moRFeus.funcCurrent, cur)
                print(self.devindex, "Current     : ", cur)
                break
            except ValueError:
                break

    # setFrequency for Qt applet,
    # mixer/generator mode which only uses a static frequency
    def statfreqQt(self):
        while self.device:
            try:
                s_freq = self.startFreq.value()
                self.moRFeus.message(self.moRFeus.SET, self.moRFeus.funcFrequency, s_freq)
                print(self.devindex, "Frequency   :  {0:8.6f}".format(s_freq), "MHz")
                break
            except ValueError:
                break

    # Set moRFeus to generator mode
    # Generator static frequency
    def genQt(self):
        self.check5400()
        self.moRFeus.message(self.moRFeus.SET, self.moRFeus.funcMixGen, 1)
        print(self.devindex, "Generator   :")

    # Set moRFeus to mixer mode
    # Mixer static frequency
    def mixQt(self):
        self.check5400()
        self.moRFeus.message(self.moRFeus.SET, self.moRFeus.funcMixGen, 0)
        print(self.devindex, "Mixer       :")

    # Set to max mixer frequency to create wideband noise
    def noiseQt(self):
        self.moRFeus.message(self.moRFeus.SET, self.moRFeus.funcMixGen, 1)
        self.curQt()
        self.moRFeus.message(self.moRFeus.SET, self.moRFeus.funcFrequency, 5400)
        self.startFreq.setValue(5400)
        print(self.devindex, 'Such Noise  :')

    # Frequency sweep routine, still needs a means to break out of
    # loop on some event..
    def sweepQt(self):
        start_freq = self.startFreq.value()
        start_freq = int(start_freq * self.moRFeus.mil)
        end_freq = self.endFreq.value()
        end_freq = int(end_freq * self.moRFeus.mil)
        step = self.stepSize.value()
        step = int(step * 1000)
        stepcount = int((end_freq - start_freq) / step)
        delay = self.delay.value()
        self.moRFeus.message(self.moRFeus.SET, self.moRFeus.funcMixGen, 1)
        self.curQt()
        y = 1
        self.moRFeus.printProgressBar(0, stepcount, prefix='Sweep :', suffix='', length=43)
        while True:
            if stepcount == 0:
                print("NULL Range  :")
                break
            else:
                for x in self.freqRange(start_freq + step, end_freq, step):
                    self.moRFeus.message(self.moRFeus.SET, self.moRFeus.funcFrequency, (x / self.moRFeus.mil))
                    self.moRFeus.printProgressBar(y, stepcount, prefix='Sweep Prog    : ', suffix='', length=43)
                    time.sleep(delay / 1000)
                    y += 1
                self.moRFeus.message(self.moRFeus.SET, self.moRFeus.funcFrequency, self.startFreq.value())
                break

    # Sending of morse code via current switch, 0 is off 1 is on
    def sendMorse(self):
        while True:
            morse_input = self.morseInput.text()
            for letter in morse_input:
                for symbol in self.morseCode.MORSE[letter.upper()]:
                    if symbol == '-':
                        self.morseCode.dash()
                    else:
                        if symbol == '.':
                            self.morseCode.dot()
                        else:
                            time.sleep(0.5)
                time.sleep(0.5)
            print(self.devindex, "Mors        :  " + morse_input)
            break
        self.curQt()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '.\moRFeusQt\morfeus_pyqt5.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_mRFsMain(object):
    def setupUi(self, mRFsMain):
        mRFsMain.setObjectName("mRFsMain")
        mRFsMain.resize(400, 300)
        mRFsMain.setMinimumSize(QtCore.QSize(400, 290))
        mRFsMain.setMaximumSize(QtCore.QSize(400, 290))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("imgs/icon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        mRFsMain.setWindowIcon(icon)
        self.centralwidget = QtWidgets.QWidget(mRFsMain)
        self.centralwidget.setMinimumSize(QtCore.QSize(400, 290))
        self.centralwidget.setMaximumSize(QtCore.QSize(400, 290))
        self.centralwidget.setObjectName("centralwidget")
        self.powerInput = QtWidgets.QSpinBox(self.centralwidget)
        self.powerInput.setGeometry(QtCore.QRect(130, 110, 161, 22))
        self.powerInput.setInputMethodHints(QtCore.Qt.ImhDigitsOnly|QtCore.Qt.ImhFormattedNumbersOnly)
        self.powerInput.setMaximum(7)
        self.powerInput.setProperty("value", 1)
        self.powerInput.setObjectName("powerInput")
        self.label_6 = QtWidgets.QLabel(self.centralwidget)
        self.label_6.setGeometry(QtCore.QRect(20, 140, 91, 16))
        self.label_6.setObjectName("label_6")
        self.biasOn = QtWidgets.QPushButton(self.centralwidget)
        self.biasOn.setGeometry(QtCore.QRect(310, 140, 75, 23))
        self.biasOn.setMaximumSize(QtCore.QSize(80, 25))
        self.biasOn.setFocusPolicy(QtCore.Qt.NoFocus)
        self.biasOn.setObjectName("biasOn")
        self.morseInput = QtWidgets.QLineEdit(self.centralwidget)
        self.morseInput.setGeometry(QtCore.QRect(130, 200, 161, 22))
        self.morseInput.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.SouthAfrica))
        self.morseInput.setObjectName("morseInput")
        self.startFreq = QtWidgets.QDoubleSpinBox(self.centralwidget)
        self.startFreq.setGeometry(QtCore.QRect(130, 20, 161, 22))
        font = QtGui.QFont()
        font.setKerning(True)
        self.startFreq.setFont(font)
        self.startFreq.setInputMethodHints(QtCore.Qt.ImhDigitsOnly|QtCore.Qt.ImhFormattedNumbersOnly)
        self.startFreq.setDecimals(6)
        self.startFreq.setMinimum(85.0)
        self.startFreq.setMaximum(5400.0)
        self.startFreq.setSingleStep(0.1)
        self.startFreq.setProperty("value", 85.0)
        self.startFreq.setObjectName("startFreq")
        self.endFreq = QtWidgets.QDoubleSpinBox(self.centralwidget)
        self.endFreq.setGeometry(QtCore.QRect(130, 50, 161, 22))
        self.endFreq.setInputMethodHints(QtCore.Qt.ImhDigitsOnly|QtCore.Qt.ImhFormattedNumbersOnly)
        self.endFreq.setDecimals(6)
        self.endFreq.setMinimum(85.0)
        self.endFreq.setMaximum(5400.0)
        self.endFreq.setProperty("value", 88.0)
        self.endFreq.setObjectName("endFreq")
        self.mixButton = QtWidgets.QPushButton(self.centralwidget)
        self.mixButton.setGeometry(QtCore.QRect(310, 20, 75, 23))
        self.mixButton.setMaximumSize(QtCore.QSize(80, 25))
        self.mixButton.setFocusPolicy(QtCore.Qt.NoFocus)
        self.mixButton.setObjectName("mixButton")
        self.label_4 = QtWidgets.QLabel(self.centralwidget)
        self.label_4.setGeometry(QtCore.QRect(20, 80, 91, 16))
        self.label_4.setObjectName("label_4")
        self.delay = QtWidgets.QSpinBox(self.centralwidget)
        self.delay.setGeometry(QtCore.QRect(130, 170, 161, 22))
        self.delay.setInputMethodHints(QtCore.Qt.ImhDigitsOnly|QtCore.Qt.ImhFormattedNumbersOnly)
        self.delay.setMaximum(10000)
        self.delay.setProperty("value", 1)
        self.delay.setObjectName("delay")
        self.genButton = QtWidgets.QPushButton(self.centralwidget)
        self.genButton.setGeometry(QtCore.QRect(310, 50, 75, 23))
        self.genButton.setMaximumSize(QtCore.QSize(80, 25))
        self.genButton.setFocusPolicy(QtCore.Qt.NoFocus)
        self.genButton.setObjectName("genButton")
        self.startLabel = QtWidgets.QLabel(self.centralwidget)
        self.startLabel.setGeometry(QtCore.QRect(20, 20, 91, 16))
        self.startLabel.setObjectName("startLabel")
        self.noiseButton = QtWidgets.QPushButton(self.centralwidget)
        self.noiseButton.setGeometry(QtCore.QRect(310, 80, 75, 23))
        self.noiseButton.setMaximumSize(QtCore.QSize(80, 25))
        self.noiseButton.setFocusPolicy(QtCore.Qt.NoFocus)
        self.noiseButton.setObjectName("noiseButton")
        self.sweepButton = QtWidgets.QPushButton(self.centralwidget)
        self.sweepButton.setGeometry(QtCore.QRect(310, 110, 75, 23))
        self.sweepButton.setMaximumSize(QtCore.QSize(80, 25))
        self.sweepButton.setFocusPolicy(QtCore.Qt.NoFocus)
        self.sweepButton.setObjectName("sweepButton")
        self.morseButton = QtWidgets.QPushButton(self.centralwidget)
        self.morseButton.setGeometry(QtCore.QRect(310, 200, 75, 23))
        self.morseButton.setMaximumSize(QtCore.QSize(80, 25))
        self.morseButton.setFocusPolicy(QtCore.Qt.NoFocus)
        self.morseButton.setObjectName("morseButton")
        self.label_7 = QtWidgets.QLabel(self.centralwidget)
        self.label_7.setGeometry(QtCore.QRect(20, 170, 91, 16))
        self.label_7.setObjectName("label_7")
        self.steps = QtWidgets.QSpinBox(self.centralwidget)
        self.steps.setGeometry(QtCore.QRect(130, 140, 161, 22))
        self.steps.setInputMethodHints(QtCore.Qt.ImhDigitsOnly|QtCore.Qt.ImhFormattedNumbersOnly)
        self.steps.setMaximum(1000)
        self.steps.setProperty("value", 5)
        self.steps.setObjectName("steps")
        self.biasOff = QtWidgets.QPushButton(self.centralwidget)
        self.biasOff.setGeometry(QtCore.QRect(310, 170, 75, 23))
        self.biasOff.setMaximumSize(QtCore.QSize(80, 25))
        self.biasOff.setFocusPolicy(QtCore.Qt.NoFocus)
        self.biasOff.setObjectName("biasOff")
        self.label_5 = QtWidgets.QLabel(self.centralwidget)
        self.label_5.setGeometry(QtCore.QRect(20, 110, 91, 16))
        self.label_5.setObjectName("label_5")
        self.stepSize = QtWidgets.QDoubleSpinBox(self.centralwidget)
        self.stepSize.setGeometry(QtCore.QRect(130, 80, 161, 22))
        self.stepSize.setInputMethodHints(QtCore.Qt.ImhDigitsOnly|QtCore.Qt.ImhFormattedNumbersOnly)
        self.stepSize.setDecimals(4)
        self.stepSize.setMinimum(0.001)
        self.stepSize.setMaximum(50000.0)
        self.stepSize.setProperty("value", 250.0)
        self.stepSize.setObjectName("stepSize")
        self.label_3 = QtWidgets.QLabel(self.centralwidget)
        self.label_3.setGeometry(QtCore.QRect(20, 50, 91, 16))
        self.label_3.setObjectName("label_3")
        self.readRegButton = QtWidgets.QPushButton(self.centralwidget)
        self.readRegButton.setGeometry(QtCore.QRect(310, 230, 75, 23))
        self.readRegButton.setMaximumSize(QtCore.QSize(80, 25))
        self.readRegButton.setFocusPolicy(QtCore.Qt.NoFocus)
        self.readRegButton.setObjectName("readRegButton")
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setGeometry(QtCore.QRect(20, 200, 81, 16))
        self.label.setObjectName("label")
        self.readReg = QtWidgets.QLineEdit(self.centralwidget)
        self.readReg.setGeometry(QtCore.QRect(130, 230, 161, 22))
        self.readReg.setInputMethodHints(QtCore.Qt.ImhDigitsOnly|QtCore.Qt.ImhFormattedNumbersOnly)
        self.readReg.setReadOnly(True)
        self.readReg.setObjectName("readReg")
        self.label_2 = QtWidgets.QLabel(self.centralwidget)
        self.label_2.setGeometry(QtCore.QRect(20, 230, 81, 16))
        self.label_2.setObjectName("label_2")
        mRFsMain.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(mRFsMain)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 400, 21))
        self.menubar.setObjectName("menubar")
        mRFsMain.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(mRFsMain)
        self.statusbar.setObjectName("statusbar")
        mRFsMain.setStatusBar(self.statusbar)
        self.label_6.setBuddy(self.steps)
        self.label_4.setBuddy(self.stepSize)
        self.startLabel.setBuddy(self.startFreq)
        self.label_7.setBuddy(self.delay)
        self.label_5.setBuddy(self.powerInput)
        self.label_3.setBuddy(self.endFreq)

        self.retranslateUi(mRFsMain)
        QtCore.QMetaObject.connectSlotsByName(mRFsMain)
        mRFsMain.setTabOrder(self.startFreq, self.endFreq)
        mRFsMain.setTabOrder(self.endFreq, self.stepSize)
        mRFsMain.setTabOrder(self.stepSize, self.powerInput)
        mRFsMain.setTabOrder(self.powerInput, self.steps)
        mRFsMain.setTabOrder(self.steps, self.delay)
        mRFsMain.setTabOrder(self.delay, self.morseInput)
        mRFsMain.setTabOrder(self.morseInput, self.readReg)

    def retranslateUi(self, mRFsMain):
        _translate = QtCore.QCoreApplication.translate
        mRFsMain.setWindowTitle(_translate("mRFsMain", "moRFeus Qt v2.369"))
        self.powerInput.setToolTip(_translate("mRFsMain", "Set Device Current"))
        self.label_6.setText(_translate("mRFsMain", "Steps"))
        self.biasOn.setToolTip(_translate("mRFsMain", "Set BiasTee On"))
        self.biasOn.setText(_translate("mRFsMain", "Bias On"))
        self.morseInput.setToolTip(_translate("mRFsMain", "Please enter message"))
        self.startFreq.setToolTip(_translate("mRFsMain", "Set the device freq"))
        self.endFreq.setToolTip(_translate("mRFsMain", "Sweep End Freq"))
        self.mixButton.setToolTip(_translate("mRFsMain", "Set Mixer Mode"))
        self.mixButton.setText(_translate("mRFsMain", "Mixer"))
        self.label_4.setText(_translate("mRFsMain", "Step KHz"))
        self.delay.setToolTip(_translate("mRFsMain", "Do you like time?"))
        self.genButton.setToolTip(_translate("mRFsMain", "Set Generator Mode"))
        self.genButton.setText(_translate("mRFsMain", "Gen"))
        self.startLabel.setText(_translate("mRFsMain", "Device Freq"))
        self.noiseButton.setToolTip(_translate("mRFsMain", "Set Noise Mode"))
        self.noiseButton.setText(_translate("mRFsMain", "Noise"))
        self.sweepButton.setToolTip(_translate("mRFsMain", "Start Freq Sweep"))
        self.sweepButton.setText(_translate("mRFsMain", "Sweep"))
        self.morseButton.setToolTip(_translate("mRFsMain", "Message at Freq"))
        self.morseButton.setText(_translate("mRFsMain", "Send"))
        self.label_7.setText(_translate("mRFsMain", "Delay ms"))
        self.steps.setToolTip(_translate("mRFsMain", "How many ?"))
        self.biasOff.setToolTip(_translate("mRFsMain", "Set BiasTee Off"))
        self.biasOff.setText(_translate("mRFsMain", "Bias Off"))
        self.label_5.setText(_translate("mRFsMain", "Power"))
        self.stepSize.setToolTip(_translate("mRFsMain", "Step Size"))
        self.label_3.setText(_translate("mRFsMain", "Sweep End"))
        self.readRegButton.setToolTip(_translate("mRFsMain", "Read Device Register"))
        self.readRegButton.setText(_translate("mRFsMain", "Read"))
        self.label.setText(_translate("mRFsMain", "Morse Code"))
        self.readReg.setToolTip(_translate("mRFsMain", "Shall I read the device?"))
        self.label_2.setText(_translate("mRFsMain", "Register"))



import sys

if sys.version_info < (3, 6):
    print("You need at least Python 3.6 for this application!")
    if sys.version_info[0] < 3:
        print("try running with python3 {}".format(" ".join(sys.argv)))
    sys.exit(1)

try:
    from setuptools import setup, find_packages
except ImportError:
    print("Could not find setuptools")
    print("Try installing them with pip install setuptools")
    sys.exit(1)

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='moRFeusQt',
    url='https://github.com/Psynosaur/moRFeus_Qt',
    version='2.639',
    author='Ohan Smit',
    author_email='psynosaur@gmail.com',
    packages=find_packages(),
    long_description=long_description,
    long_description_content_type="text/markdown",
    license='LICENSE.txt',
    entry_points={
        'console_scripts': [
            'moRFeusQt = moRFeusQt.__main__:main'
        ],
    },
    install_requires=[
        'PyQt5==5.11.2',
        'hidapi',
    ],
    test_suite='tests.mRF_test_suite',

)



import hid
import unittest
import os, sys
from moRFeusQt import mrf
sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))


class TestMRFs(unittest.TestCase):

    @classmethod
    def mockdevice(cls):
        # hard code the opening of the morfeus device and return
        td = hid.device()
        td.open(mrf.MoRFeus.vendorID, mrf.MoRFeus.productID)
        td.set_nonblocking(0)
        return td

    def test_find(self):
        # If the device isn't found, test do not continue
        cond = mrf.MoRFeus.find()
        print(cond, "Devices found")
        self.assertTrue((cond >= 1))

    def test_initdevice(self):
        # init two test devices, one from morfeus class and another from mockdevice
        devicecount = mrf.MoRFeus.find()
        devices = []
        testdevices = []
        for i in range(0, devicecount):
            devices.append(mrf.MoRFeus.initdevice(index=i))
            testdevices.append(devices[i])
            # testdevices.append(self.mockdevice())
            # Check types
            self.assertEqual(type(devices[i]), type(testdevices[i]))
            # Check if 'td1' is and instance of type 'td2'(hard opened hid.device)
            self.assertIsInstance(devices[i], type(testdevices[i]))
            # Close the devices
            devices[i].close()


if __name__ == "__main__":
    unittest.main()
